FirebaseFunctionsException class

Generic exception related to Cloud Functions. Check the error code and message for more details.

Inheritance
  • Object
  • FirebaseException
  • FirebaseFunctionsException
Implemented types

Constructors

FirebaseFunctionsException({required String message, required String code, StackTrace? stackTrace, dynamic details})

Properties

code → String
The optional code to accommodate the message.
finalinherited
details → dynamic
Additional data provided with the exception.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
The long form message of the exception.
finalinherited
plugin → String
The plugin the exception is for.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
The stack trace which provides information to the user about the call sequence that triggered an exception
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited