TimeLimit class
Creates an AbortSignal that will automatically abort after a specified time.
This is equivalent to calling AbortSignal.timeout(ms) in the Web SDK.
Typically used to cancel long-running operations after a timeout duration.
Example:
final signal = HttpsCallableOptions(webAbortSignal: TimeLimit(Duration(seconds: 10)));
- Inheritance
-
- Object
- AbortSignal
- TimeLimit
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited